netapp_ontap.models.volume_protocol_raw_performance_stats API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_protocol_raw_performance_stats`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeProtocolRawPerformanceStatsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeProtocolRawPerformanceStats object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `access: VolumeProtocolRawPerformanceStatOther GET`

    The access field of the volume_protocol_raw_performance_stats.

  `audit: VolumeProtocolRawPerformanceStatOther GET`

    The audit field of the volume_protocol_raw_performance_stats.

  `create: VolumeProtocolRawPerformanceStatCreate GET`

    The create field of the volume_protocol_raw_performance_stats.

  `getattr: VolumeProtocolRawPerformanceStatOther GET`

    The getattr field of the volume_protocol_raw_performance_stats.

  `link: VolumeProtocolRawPerformanceStatOther GET`

    The link field of the volume_protocol_raw_performance_stats.

  `lock: VolumeProtocolRawPerformanceStatOther GET`

    The lock field of the volume_protocol_raw_performance_stats.

  `lookup: VolumeProtocolRawPerformanceStatOther GET`

    The lookup field of the volume_protocol_raw_performance_stats.

  `open: VolumeProtocolRawPerformanceStatOther GET`

    The open field of the volume_protocol_raw_performance_stats.

  `read: VolumeProtocolRawPerformanceStatRw GET`

    The read field of the volume_protocol_raw_performance_stats.

  `readdir: VolumeProtocolRawPerformanceStatOther GET`

    The readdir field of the volume_protocol_raw_performance_stats.

  `readlink: VolumeProtocolRawPerformanceStatOther GET`

    The readlink field of the volume_protocol_raw_performance_stats.

  `rename: VolumeProtocolRawPerformanceStatOther GET`

    The rename field of the volume_protocol_raw_performance_stats.

  `setattr: VolumeProtocolRawPerformanceStatOther GET`

    The setattr field of the volume_protocol_raw_performance_stats.

  `unlink: VolumeProtocolRawPerformanceStatOther GET`

    The unlink field of the volume_protocol_raw_performance_stats.

  `watch: VolumeProtocolRawPerformanceStatOther GET`

    The watch field of the volume_protocol_raw_performance_stats.

  `write: VolumeProtocolRawPerformanceStatRw GET`

    The write field of the volume_protocol_raw_performance_stats.